@@ -23,14 +23,10 @@
  ***************************************************************************/
 
 #include "winecollection.h"
+#include "../core/tellico_strings.h"
 
 #include <KLocalizedString>
 
-namespace {
-  static const char* wine_general = I18N_NOOP("General");
-  static const char* wine_personal = I18N_NOOP("Personal");
-}
-
 using Tellico::Data::WineCollection;
 
 WineCollection::WineCollection(bool addDefaultFields_, const QString& title_)
@@ -52,71 +48,71 @@ Tellico::Data::FieldList WineCollection::defaultFields() {
   list.append(field);
 
   field = new Field(QStringLiteral("producer"), i18nc("Wine Producer", "Producer"));
-  field->setCategory(i18n(wine_general));
+  field->setCategory(TC_I18N1(categoryGeneral));
   field->setFlags(Field::AllowCompletion | Field::AllowGrouped);
   field->setFormatType(FieldFormat::FormatPlain);
   list.append(field);
 
   field = new Field(QStringLiteral("appellation"), i18n("Appellation"));
-  field->setCategory(i18n(wine_general));
+  field->setCategory(TC_I18N1(categoryGeneral));
   field->setFlags(Field::AllowCompletion | Field::AllowGrouped);
   field->setFormatType(FieldFormat::FormatPlain);
   list.append(field);
 
   field = new Field(QStringLiteral("varietal"), i18n("Varietal"));
-  field->setCategory(i18n(wine_general));
+  field->setCategory(TC_I18N1(categoryGeneral));
   field->setFlags(Field::AllowCompletion | Field::AllowGrouped);
   field->setFormatType(FieldFormat::FormatPlain);
   list.append(field);
 
   field = new Field(QStringLiteral("vintage"), i18n("Vintage"), Field::Number);
-  field->setCategory(i18n(wine_general));
+  field->setCategory(TC_I18N1(categoryGeneral));
   field->setFlags(Field::AllowGrouped);
   list.append(field);
 
   QStringList type;
   type << i18n("Red Wine") << i18n("White Wine") << i18n("Sparkling Wine");
   field = new Field(QStringLiteral("type"), i18n("Type"), type);
-  field->setCategory(i18n(wine_general));
+  field->setCategory(TC_I18N1(categoryGeneral));
   field->setFlags(Field::AllowGrouped);
   list.append(field);
 
   field = new Field(QStringLiteral("country"), i18n("Country"));
-  field->setCategory(i18n(wine_general));
+  field->setCategory(TC_I18N1(categoryGeneral));
   field->setFlags(Field::AllowCompletion | Field::AllowGrouped);
   field->setFormatType(FieldFormat::FormatPlain);
   list.append(field);
 
   field = new Field(QStringLiteral("pur_date"), i18n("Purchase Date"));
-  field->setCategory(i18n(wine_personal));
+  field->setCategory(TC_I18N1(categoryPersonal));
   field->setFormatType(FieldFormat::FormatDate);
   list.append(field);
 
   field = new Field(QStringLiteral("pur_price"), i18n("Purchase Price"));
-  field->setCategory(i18n(wine_personal));
+  field->setCategory(TC_I18N1(categoryPersonal));
   list.append(field);
 
   field = new Field(QStringLiteral("location"), i18n("Location"));
-  field->setCategory(i18n(wine_personal));
+  field->setCategory(TC_I18N1(categoryPersonal));
   field->setFlags(Field::AllowCompletion | Field::AllowGrouped);
   list.append(field);
 
   field = new Field(QStringLiteral("quantity"), i18n("Quantity"), Field::Number);
-  field->setCategory(i18n(wine_personal));
+  field->setCategory(TC_I18N1(categoryPersonal));
   list.append(field);
 
   field = new Field(QStringLiteral("drink-by"), i18n("Drink By"), Field::Number);
-  field->setCategory(i18n(wine_personal));
+  field->setCategory(TC_I18N1(categoryPersonal));
   field->setFlags(Field::AllowGrouped);
   list.append(field);
 
   field = new Field(QStringLiteral("rating"), i18n("Rating"), Field::Rating);
-  field->setCategory(i18n(wine_personal));
+  field->setCategory(TC_I18N1(categoryPersonal));
   field->setFlags(Field::AllowGrouped);
   list.append(field);
 
   field = new Field(QStringLiteral("gift"), i18n("Gift"), Field::Bool);
-  field->setCategory(i18n(wine_personal));
+  field->setCategory(TC_I18N1(categoryPersonal));
   list.append(field);
 
   field = new Field(QStringLiteral("label"), i18n("Label Image"), Field::Image);
