@@ -380,8 +380,8 @@ void Z3950Connection::run() {
 #endif
       data = toXML(ZOOM_record_get(rec, "raw", &len), m_responseCharSet);
     }
-    Z3950ResultFound* ev = new Z3950ResultFound(data);
     if(m_fetcher) {
+      auto ev = new Z3950ResultFound(data);
       QApplication::postEvent(m_fetcher.data(), ev);
     }
   }
@@ -565,7 +565,7 @@ QString Z3950Connection::toXML(const QByteArray& marc_, const QString& charSet_)
   size_t len = marc_.left(5).toInt(&ok);
 #endif
   if(ok && (len < 25 || len > 100000)) {
-    myDebug() << "bad length:" << (ok ? len : -1);
+    myDebug() << "bad length:" << len;
     return QString();
   }
 
