@@ -118,7 +118,7 @@ void OpenLibraryFetcherTest::testIsbn13() {
   QCOMPARE(entry->field(QStringLiteral("pub_year")), QStringLiteral("1995"));
   QCOMPARE(entry->field(QStringLiteral("binding")), QStringLiteral("Paperback"));
   QCOMPARE(entry->field(QStringLiteral("series")), QStringLiteral("Vorkosigan Saga"));
-  QVERIFY(entry->field(QStringLiteral("openlibrary-work")).isEmpty()); // temporary field should not exist
+  QVERIFY(!entry->field(QStringLiteral("plot")).isEmpty());
   QVERIFY(!entry->field(QStringLiteral("cover")).isEmpty());
   QVERIFY(!entry->field(QStringLiteral("cover")).contains(QLatin1Char('/')));
 }
@@ -150,6 +150,12 @@ void OpenLibraryFetcherTest::testLccn() {
   QCOMPARE(entry->field(QStringLiteral("pages")), QStringLiteral("56"));
   QCOMPARE(entry->field(QStringLiteral("openlibrary")), QStringLiteral("https://openlibrary.org/books/OL3315616M"));
   QVERIFY(!entry->field(QStringLiteral("comments")).isEmpty());
+
+  //https://bugs.kde.org/show_bug.cgi?id=508897
+  auto f = static_cast<Tellico::Fetch::OpenLibraryFetcher*>(fetcher.data());
+  request = f->updateRequest(entry);
+  QCOMPARE(request.key(), Tellico::Fetch::Raw);
+  QCOMPARE(request.value(), QStringLiteral("key=/books/OL3315616M"));
 }
 
 void OpenLibraryFetcherTest::testMultipleIsbn() {
@@ -203,4 +209,28 @@ void OpenLibraryFetcherTest::testComic() {
   QCOMPARE(entry->collection()->type(), Tellico::Data::Collection::ComicBook);
   QCOMPARE(entry->field(QStringLiteral("title")), QString::fromUtf8("よつばと！ 1"));
   QCOMPARE(entry->field(QStringLiteral("isbn")), QStringLiteral("4-04869066-3"));
+  QCOMPARE(entry->field(QStringLiteral("writer")), QStringLiteral("あずまきよひこ"));
+  QVERIFY(!entry->field(QStringLiteral("plot")).isEmpty());
+}
+
+//https://bugs.kde.org/show_bug.cgi?id=507912
+void OpenLibraryFetcherTest::testBug507912() {
+  Tellico::Fetch::FetchRequest request(Tellico::Data::Collection::Book, Tellico::Fetch::Raw,
+                                       QStringLiteral("key=/books/OL32223354M"));
+  Tellico::Fetch::Fetcher::Ptr fetcher(new Tellico::Fetch::OpenLibraryFetcher(this));
+//  QVERIFY(fetcher->canSearch(request.key()));
+
+  Tellico::Data::EntryList results = DO_FETCH1(fetcher, request, 1);
+  QVERIFY(!results.isEmpty());
+
+  Tellico::Data::EntryPtr entry = results.at(0);
+  QCOMPARE(entry->collection()->type(), Tellico::Data::Collection::Book);
+  QCOMPARE(entry->field(QStringLiteral("title")), QStringLiteral("Sonnets. Volume 8"));
+  QCOMPARE(entry->field(QStringLiteral("author")), QStringLiteral("William Shakespeare"));
+  QVERIFY(entry->field(QStringLiteral("isbn")).isEmpty()); // test case has to lack an isbn
+  QVERIFY(entry->field(QStringLiteral("openlibrary")).isEmpty()); // verify the link is not included
+  QVERIFY(!entry->collection()->hasField(QStringLiteral("openlibrary"))); // verify the link is not included
+  QVERIFY(!entry->field(QStringLiteral("plot")).isEmpty());
+  QVERIFY(!entry->field(QStringLiteral("cover")).isEmpty());
+  QVERIFY(!entry->field(QStringLiteral("cover")).contains(QLatin1Char('/')));
 }
