@@ -46,13 +46,13 @@ public:
   ONIXExporter(Data::CollPtr coll);
   ~ONIXExporter();
 
-  virtual bool exec() Q_DECL_OVERRIDE;
-  virtual QString formatString() const Q_DECL_OVERRIDE;
-  virtual QString fileFilter() const Q_DECL_OVERRIDE;
+  virtual bool exec() override;
+  virtual QString formatString() const override;
+  virtual QString fileFilter() const override;
 
-  virtual QWidget* widget(QWidget*) Q_DECL_OVERRIDE;
-  virtual void readOptions(KSharedConfigPtr) Q_DECL_OVERRIDE;
-  virtual void saveOptions(KSharedConfigPtr) Q_DECL_OVERRIDE;
+  virtual QWidget* widget(QWidget*) override;
+  virtual void readOptions(KSharedConfigPtr) override;
+  virtual void saveOptions(KSharedConfigPtr) override;
 
   QString text();
 
