@@ -83,7 +83,7 @@ Tellico::Data::CollPtr TellicoImporter::collection() {
 
   // need to decide if the data is xml text, or a zip file
   // if the first 5 characters are <?xml then treat it like text
-  if(s[0] == '<' && s[1] == '?' && s[2] == 'x' && s[3] == 'm' && s[4] == 'l') {
+  if(s.size() >= 5 && s[0] == '<' && s[1] == '?' && s[2] == 'x' && s[3] == 'm' && s[4] == 'l') {
     m_format = XML;
     loadXMLData(source() == URL ? fileRef().file()->readAll() : data(), true);
   } else {
@@ -99,6 +99,7 @@ void TellicoImporter::loadXMLData(const QByteArray& data_, bool loadImages_) {
   TellicoXmlReader reader(m_baseUrl);
   reader.setLoadImages(loadImages_);
   reader.setShowImageLoadErrors(options() & ImportShowImageErrors);
+  reader.setImagePathsAsLinks(options() & ImportImagesAsLinks);
   bool success = true;
 
   const int blockSize = qMax(data_.size()/100 + 1, MIN_BLOCK_SIZE);
