@@ -107,6 +107,10 @@ void TellicoXmlReader::setShowImageLoadErrors(bool showImageErrors_) {
   m_data->showImageLoadErrors = showImageErrors_;
 }
 
+void TellicoXmlReader::setImagePathsAsLinks(bool imagePathsAsLinks_) {
+  m_data->imagePathsAsLinks = imagePathsAsLinks_;
+}
+
 void TellicoXmlReader::handleStart() {
   SAX::StateHandler* handler = m_handlers.top()->nextHandler(m_xml.namespaceUri(), m_xml.name());
   Q_ASSERT(handler);
